@@ -61,7 +61,6 @@ class TestLooponFailing:
         """)
         session = LooponfailingSession(modcol.config)
         loopstate = LoopState()
-        session.remotecontrol.setup()
         session.loop_once(loopstate)
         assert len(loopstate.colitems) == 1
  
@@ -83,7 +82,6 @@ class TestLooponFailing:
         """)
         session = LooponfailingSession(modcol.config)
         loopstate = LoopState()
-        session.remotecontrol.setup()
         loopstate.colitems = []
         session.loop_once(loopstate)
         assert len(loopstate.colitems) == 1
@@ -110,7 +108,6 @@ class TestLooponFailing:
         """)
         session = LooponfailingSession(modcol.config)
         loopstate = LoopState()
-        session.remotecontrol.setup()
         loopstate.colitems = []
         session.loop_once(loopstate)
         assert len(loopstate.colitems) == 2
@@ -135,7 +132,7 @@ class TestLooponFailing:
                 x = 0
                 assert x == 1
         """)
-        child = testdir.spawn_pytest("-f %s" % p)
+        child = testdir.spawn_pytest("-f %s --traceconfig" % p)
         child.expect("def test_one")
         child.expect("x == 1")
         child.expect("1 failed")
@@ -149,3 +146,16 @@ class TestLooponFailing:
         child.expect(".*1 passed.*")
         child.kill(15)
 
+    def test_looponfail_xfail_passes(self, testdir):
+        p = testdir.makepyfile("""
+            import py
+            @py.test.mark.xfail
+            def test_one():
+                pass
+        """)
+        child = testdir.spawn_pytest("-f %s" % p)
+        child.expect("1 xpass")
+        child.expect("### LOOPONFAILING ####")
+        child.expect("waiting for changes")
+        child.kill(15)
+
